import time
from calendar import monthrange

from netforce.model import Model,fields,get_model
from netforce.access import get_active_company

class ReportLaborCostDaily(Model):
    _name="clinic.report.labor.cost.daily"
    _string="Report Labor Cost Daily"
    _transient=True
    
    _fields={
        "date": fields.Date("Date"),
        "type": fields.Selection([["doctor","Doctor"],["nurse","Nurse"],["staff","Staff"]],"Type"),
        'staff_id': fields.Many2One("clinic.staff","Staff"),
    }

    def _get_date_from(self,context={}):
        year,month=time.strftime("%Y-%m").split("-")
        return '%s-%s-01'%(year,month)

    def _get_date_to(self,context={}):
        year,month,day=time.strftime("%Y-%m-%d").split("-")
        weekday, total_day=monthrange(int(year), int(month))
        return "%s-%s-%s"%(year,month,total_day)

    _defaults={
        'date': lambda *a: time.strftime("%Y-%m-%d"),
    }
    
    def get_report_data(self,ids,context={}):
        fmt='%Y-%m-%d'
        date=time.strftime(fmt)
        company_id=get_active_company()
        comp=get_model("company").browse(company_id)
        staff_type=None
        staff_id=None
        dom=[]
        if ids:
            obj=self.browse(ids)[0]
            date=obj.date
            staff_id=obj.staff_id.id
            staff_type=obj.type
        dom.append(['date','>=',date])
        dom.append(['date','<=',date])
        # prevent to load more
        if not staff_id:
            return {}
        if staff_id:
            dom.append(['staff_id','=',staff_id])
        if staff_type:
            dom.append(['type','=',staff_type])
        lines=[]
        no=1
        for line in get_model("clinic.labor.cost.line").search_browse(dom):
            lcost=line.labor_cost_id
            citem=lcost.cycle_item_id
            cycle=citem.cycle_id
            staff=line.staff_id
            dpt=citem.department_id
            amt=line.amount or 0
            if staff_type=='doctor':
                for hdcase in citem.hd_cases:
                    doctor=hdcase.doctor_id
                    pt_type=hdcase.patient_type_id
                    pt=hdcase.patient_id
                    if staff.id==doctor.id:
                        lines.append({
                            'no': no,
                            'hn': pt.number,
                            'patient_id': pt.id,
                            'patient_name': pt.name or '',
                            'patient_type_name': pt_type.name or '',
                            'amount': amt,
                            'dpt_id': dpt.id,
                            'dpt_name': dpt.name or "",
                            'cycle_name': cycle.name,
                            'cycle_id': cycle.id,
                        })
                        no+=1
            elif staff_type=='nurse':
                for hdcase in citem.hd_cases:
                    doctor=hdcase.doctor_id
                    pt_type=hdcase.patient_type_id
                    pt=hdcase.patient_id
                    lines.append({
                        'no': no,
                        'hn': pt.number,
                        'patient_id': pt.id,
                        'patient_type_name': pt_type.name or '',
                        'patient_name': pt.name or '',
                        'dpt_id': dpt.id,
                        'dpt_name': dpt.name or "",
                        'amount': 0,
                        'cycle_name': cycle.name,
                        'cycle_id': cycle.id,
                    })
                    no+=1
            else:
                continue
        data={
            'staff_type': staff_type,
            'date': date,
            'comp_name': comp.name or 0,
            'lines': lines,
        }
        return data

    def onchange_type(self,context={}):
        data=context['data']
        data['staff_id']=None
        return data

ReportLaborCostDaily.register()
